RDMO - Research Data Management Organiser
=========================================

[![pytest Workflow Status](https://github.com/rdmorganiser/rdmo/actions/workflows/pytest.yml/badge.svg)](https://github.com/rdmorganiser/rdmo/actions/workflows/pytest.yml)
[![Coverage Status](https://coveralls.io/repos/rdmorganiser/rdmo/badge.svg?branch=master&service=github)](https://coveralls.io/github/rdmorganiser/rdmo?branch=master)
[![Latest Version](https://img.shields.io/pypi/v/rdmo.svg?style=flat)](https://pypi.python.org/pypi/rdmo/)
[![Documentation status](https://readthedocs.org/projects/rdmo/badge/?version=latest)](http://rdmo.readthedocs.io/en/latest/?badge=latest)
[![License](http://img.shields.io/badge/license-APACHE-blue.svg?style=flat)](https://github.com/rdmorganiser/rdmo/blob/master/LICENSE)
[![Updates](https://pyup.io/repos/github/rdmorganiser/rdmo/shield.svg)](https://pyup.io/repos/github/rdmorganiser/rdmo/)

RDMO is a tool to support the systematic planning, organisation and implementation of the data management throughout the course of a research project. RDMO is funded by the Deutsche Forschungsgemeinschaft (DFG).

<dl>
  <dt>Home Page</dt>
  <dd>https://rdmorganiser.github.io</dd>
  <dt>Source code</dt>
  <dd>https://github.com/rdmorganiser/rdmo</dd>
  <dt>Documentation</dt>
  <dd>http://rdmo.readthedocs.io</dd>
  <dt>Mailing list</dt>
  <dd>https://www.listserv.dfn.de/sympa/subscribe/rdmo</dd>
  <dt>Slack</dt>
  <dd>https://rdmo.slack.com</dd>
  <dt>Demo</dt>
  <dd>https://rdmo.aip.de</dd>
</dl>

If you encounter any problems or bugs with the RDMO Software, or if you want to request a feature, please file an issue here: https://github.com/rdmorganiser/rdmo/issues. For problems or suggestions with questionaires, the RDMO domain model or other content, please use the issues in the [rdmo-catalog](https://github.com/rdmorganiser/rdmo-catalog) repository: https://github.com/rdmorganiser/rdmo-catalog/issues. In order to file issues, you will need a GitHub account.
